﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace InfragisticsSpin
{
	/// <summary>
	/// DataFilter used to allow the end user to edit percentages using
	/// whole numbers but storing the value as a fraction.
	/// </summary>
	public class PercentageDataFilter : Infragistics.Win.IEditorDataFilter
	{
		/// <summary>
		/// Converts data between Display (user), Editor and Owner (data source).
		/// </summary>
		/// <param name="conversionArgs">Input arguments.</param>
		/// <returns>Converted data.</returns>
		public object Convert(Infragistics.Win.EditorDataFilterConvertArgs conversionArgs)
		{
			switch (conversionArgs.Direction)
			{
				case Infragistics.Win.ConversionDirection.EditorToOwner:
					{
						// only convert non null values
						if (conversionArgs.Value != null &&
							!(conversionArgs.Value is DBNull) &&
							conversionArgs.Value is IConvertible)
						{
							// get the value from the editor as a decimal
							decimal value = System.Convert.ToDecimal(conversionArgs.Value);

							// let the editor know we handled the conversion
							conversionArgs.Handled = true;

							// divide by 100 so we store values from
							// 0 to 1 in the database
							// e.g. if the user entered 50 into the 
							// editor, then return .50 to the 
							return value / 100m;
						}
						break;
					}
				case Infragistics.Win.ConversionDirection.OwnerToEditor:
					{
						// only convert non null values
						if (conversionArgs.Value != null &&
							!(conversionArgs.Value is DBNull) &&
							conversionArgs.Value is IConvertible)
						{
							// get the decimal value that the owner has
							decimal value = System.Convert.ToDecimal(conversionArgs.Value);

							// let the editor know we handled the conversion
							conversionArgs.Handled = true;

							// multiply by 100. 
							// e.g. if the db has .10 then the user will see and edit 10
							return (int)(value * 100);
						}
						break;
					}

			}

			// by default return null. as long as we don't indicate
			// that we handled the conversion (by setting conversionArgs.Handled
			// to true), the result will be ignored.
			return null;
		}
	}
}
